@@ -9,7 +9,7 @@ use Storable;
 use Data::Dumper;
 use Log::Log4perl qw(:easy);
 
-our $VERSION = '0.35';
+our $VERSION = '0.36';
 
    # Define the mandatory and optional parameters for every method.
 our $OPTIONS = {
@@ -140,6 +140,9 @@ our $OPTIONS = {
                     optional  => [qw(heartbeat minimum maximum 
                                      type name)],
                   },
+    first      => { mandatory => [],
+                    optional  => [],
+                  },
     last       => { mandatory => [],
                     optional  => [],
                   },
@@ -165,6 +168,7 @@ my %RRDs_functions = (
     dump      => \&RRDs::dump,
     restore   => \&RRDs::restore,
     tune      => \&RRDs::tune,
+    first     => \&RRDs::first,
     last      => \&RRDs::last,
     info      => \&RRDs::info,
     rrdresize => \&RRDs::rrdresize,
@@ -1032,6 +1036,14 @@ sub info {
     return $h;
 }
 
+#################################################
+sub first {
+#################################################
+    my($self) = @_;
+
+    $self->RRDs_execute("first", $self->{file});
+}
+
 #################################################
 sub last {
 #################################################
@@ -1989,6 +2001,10 @@ Feed a perl structure with RRA data (Cf. rrdxport man page).
 Grabs the RRD's meta data and returns it as a hashref, holding a
 map of parameter names and their values.
 
+=item I<my $time = $rrd-E<gt>first()>
+
+Return the RRD's first update time.
+
 =item I<my $time = $rrd-E<gt>last()>
 
 Return the RRD's last update time.
